searchData={"items":[{"type":"module","title":"Criterion","doc":"A frame work to write unit tests as a list of steps. It can be used to write tests BDD style.","ref":"Criterion.html"},{"type":"module","title":"Usage - Criterion","doc":"1. Define scenarios using the `scenario/2` macro.\n2. Inside each scenario, define steps using the `step/2` macro.\n3. Steps can be either plain steps or steps with context variables.\n4. Shared steps can be defined external to the scenario","ref":"Criterion.html#module-usage"},{"type":"module","title":"Example - Criterion","doc":"```elixir\n# Define a scenario\nstep \"Shared\", context do\n  context\nend\n\nscenario \"Adding numbers\" do\n  # Use a shared step\n  step \"Shared\"\n  # Define a step\n  step \"Addition\" do\n    assert 1 + 1 == 2\n  end\n\n\n\n  # Define a step with context\n  step \"Addition with context\", context do\n    result = context[:a] + context[:b]\n    assert result == 5\n  end\nend\n```","ref":"Criterion.html#module-example"},{"type":"macro","title":"Criterion.scenario/3","doc":"","ref":"Criterion.html#scenario/3"},{"type":"macro","title":"Criterion.step/3","doc":"","ref":"Criterion.html#step/3"},{"type":"module","title":"Criterion.SharedSteps","doc":"","ref":"Criterion.SharedSteps.html"},{"type":"function","title":"Criterion.SharedSteps.shared_step/2","doc":"","ref":"Criterion.SharedSteps.html#shared_step/2"},{"type":"extras","title":"Criterion","doc":"# Criterion\n\nA library to write ExUnit tests BDD style","ref":"readme.html"},{"type":"extras","title":"Installation - Criterion","doc":"The package can be installed\nby adding `criterion` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:criterion, \"~> 0.1.0\", only: [:test]}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage - Criterion","doc":"```elixir\ndefmodule CriterionTest do\n  use ExUnit.Case\n  import Criterion\n\n  scenario \"Square\" do\n    step \"Given a number 2\" do\n      number = 2\n      %{number: number}\n    end\n\n    step \"When the number is multiplied by it self\", %{number: number} do\n      result = number * number\n      %{result: result}\n    end\n\n    step \"Then the result is 4\", %{result: result} do\n      assert result == 4\n      %{result: result}\n    end\n  end\nend\n\n```","ref":"readme.html#usage"},{"type":"extras","title":"Shared Steps - Criterion","doc":"```elixir\ndefmodule Criterion.SharedSteps do\n  import Criterion\n\n  step \"Given a number 2\", _context do\n    %{number: 2}\n  end\nend\n```\n\n```elixir\ndefmodule CriterionTest do\n  use ExUnit.Case\n  import Criterion\n  import Criterion.SharedSteps\n\n  scenario \"Square\" do\n    step(\"Given a number 2\")\n    step \"When the number is multiplied by it self\", %{number: number} do\n      result = number * number\n      %{result: result}\n    end\n\n    step \"Then the result is 4\", %{result: result, number: number} do\n      assert result == 4\n      assert result / number == number\n      %{result: result}\n    end\n  end\nend\n```","ref":"readme.html#shared-steps"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,49]}}